import requests 
from requests.auth import HTTPBasicAuth
import base64
import json

class Ravencoin:
    def __init__(self, username, password, host='localhost', port=8766):
        self.username = username
        self.password = password 
        self.host = host
        self.port = port
        self.id = 0 
    
    def __getattr__(self, name):
        if name.startswith('__') and name.endswith('__'):
            # Python internal stuff
            raise AttributeError

        def ret(*args):
            self.id += 1
            url = f'http://{self.host}:{self.port}'
            auth = HTTPBasicAuth(self.username, self.password)
            data = {
                'method': name,
                'params': list(args),
                'id': self.id,
                'jsonrpc': '2.0',
            }
            response = requests.post(url, json.dumps(data), headers={'Content-Type': 'application/json'}, auth=auth)
            if 'error' in response and response['error'] != None:
                raise Exception(response['error'])
            return json.loads(response.text)

        return ret



import setuptools

with open("ravenrpc/README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ravenrpc", # Replace with your own username
    version="0.2.3",
    author="JonPizza",
    author_email="jon@jon.network",
    description="Ravencoin RPC client",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/JonPizza/ravenrpc",
    packages=['ravenrpc'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
